@@ -16,16 +16,17 @@ sub run {
   my $options = {};
   GetOptionsFromArray \@args,
     'a|args=s' => sub { $args = decode_json($_[1]) },
-    'd|delay=i' => sub { $options->{delay} = $_[1] },
+    'd|delay=i'    => \$options->{delay},
     'e|enqueue=s'  => \my $enqueue,
     'L|limit=i'    => \(my $limit = 100),
-    'p|priority=i' => sub { $options->{priority} = $_[1] },
+    'p|priority=i' => \$options->{priority},
     'r|remove'     => \my $remove,
     'R|retry'      => \my $retry,
     's|stats'      => \my $stats,
-    'S|skip=i' => \(my $skip = 0),
-    'T|state=s' => \(my $state),
-    'w|workers' => \my $workers;
+    'S|skip=i'     => \(my $skip = 0),
+    't|task=s'     => \$options->{task},
+    'T|state=s'    => \$options->{state},
+    'w|workers'    => \my $workers;
   my $id = @args ? shift @args : undef;
 
   # Enqueue
@@ -35,7 +36,7 @@ sub run {
   # Show stats or list jobs/workers
   return $self->_stats if $stats;
   my $sub = $workers ? \&_list_workers : \&_list_jobs;
-  return $self->$sub($skip, $limit, $state) unless $id;
+  return $self->$sub($skip, $limit, $options) unless $id;
   die "Job does not exist.\n" unless my $job = $self->app->minion->job($id);
 
   # Remove job
@@ -72,9 +73,9 @@ sub _info {
 }
 
 sub _list_jobs {
-  my ($self, $skip, $limit, $state) = @_;
+  my ($self, $skip, $limit, $options) = @_;
   say sprintf '%s  %-8s  %s', @$_{qw(id state task)}
-    for @{$self->app->minion->backend->list_jobs($skip, $limit, $state)};
+    for @{$self->app->minion->backend->list_jobs($skip, $limit, $options)};
 }
 
 sub _list_workers {
@@ -107,7 +108,7 @@ Minion::Command::minion::job - Minion job command
   Usage: APPLICATION minion job [ID]
 
     ./myapp.pl minion job
-    ./myapp.pl minion job -T inactive
+    ./myapp.pl minion job -t test -T inactive
     ./myapp.pl minion job -e foo -a '[23, "bar"]'
     ./myapp.pl minion job -e foo -p 5
     ./myapp.pl minion job -s
@@ -127,6 +128,7 @@ Minion::Command::minion::job - Minion job command
     -s, --stats               Show queue statistics.
     -S, --skip <number>       Number of jobs/workers to skip when listing
                               them, defaults to 0.
+    -t, --task <name>         List only jobs for this task.
     -T, --state <state>       List only jobs in this state.
     -w, --workers             List workers instead of jobs.
 
